#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['tinycss2']

package_data = \
{'': ['*']}

install_requires = \
['webencodings >=0.4']

extras_require = \
{'doc': ['sphinx', 'sphinx_rtd_theme'],
 'test': ['pytest',
          'pytest-cov',
          'pytest-flake8',
          'pytest-isort',
          'coverage[toml]']}

setup(name='tinycss2',
      version='1.1.0',
      description='tinycss2',
      author='Simon Sapin',
      author_email='simon.sapin@exyr.org',
      url='https://www.courtbouillon.org/tinycss2',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
